# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEDDriverMerk(KeuzelijstField):
    """Het merk van de LED-driver."""
    naam = 'KlLEDDriverMerk'
    label = 'LED-driver merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEDDriverMerk'
    definition = 'Het merk van de LED-driver.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEDDriverMerk'
    options = {
        'inventronics': KeuzelijstWaarde(invulwaarde='inventronics',
                                         label='Inventronics',
                                         status='ingebruik',
                                         definitie='Inventronics',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverMerk/inventronics'),
        'mean-well': KeuzelijstWaarde(invulwaarde='mean-well',
                                      label='Mean Well',
                                      status='ingebruik',
                                      definitie='Mean Well',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverMerk/mean-well'),
        'osram': KeuzelijstWaarde(invulwaarde='osram',
                                  label='OSRAM',
                                  status='ingebruik',
                                  definitie='OSRAM',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverMerk/osram'),
        'philips': KeuzelijstWaarde(invulwaarde='philips',
                                    label='PHILIPS',
                                    status='ingebruik',
                                    definitie='PHILIPS',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverMerk/philips'),
        'signify': KeuzelijstWaarde(invulwaarde='signify',
                                    label='Signify',
                                    status='ingebruik',
                                    definitie='Signify',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverMerk/signify')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BetonnenConstructieElement import BetonnenConstructieElement
from ...Classes.Onderdeel.Funderingspaal import Funderingspaal
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class BetonnenSchroefpaal(BetonnenConstructieElement, Funderingspaal):
    """Met behulp van een schroefas in de grond gevormde, geluidsarme en trillingsvrije funderingspaal met volledige wegpersing van de grond over de volledige paallengte."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenSchroefpaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._heeftVerlorenVoerbuis = OTLAttribuut(field=BooleanField,
                                                   naam='heeftVerlorenVoerbuis',
                                                   label='heeft verloren voerbuis',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenSchroefpaal.heeftVerlorenVoerbuis',
                                                   definition='Geeft aan of de betonnen schroefpaal een verloren schroefbuis heeft of niet.',
                                                   owner=self)

        self._nuttigeLengte = OTLAttribuut(field=KwantWrdInMeter,
                                           naam='nuttigeLengte',
                                           label='nuttige lengte',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenSchroefpaal.nuttigeLengte',
                                           definition='Afstand gemeten, in meter, volgens de as van de schroefpaal tussen het aanzetpeil van de funderingszool boven de werkvloer (of, in geval van een vrijstaande paal, het afkappeil) en het aanzetpeil (definitief funderingspeil).',
                                           owner=self)

    @property
    def heeftVerlorenVoerbuis(self) -> bool:
        """Geeft aan of de betonnen schroefpaal een verloren schroefbuis heeft of niet."""
        return self._heeftVerlorenVoerbuis.get_waarde()

    @heeftVerlorenVoerbuis.setter
    def heeftVerlorenVoerbuis(self, value):
        self._heeftVerlorenVoerbuis.set_waarde(value, owner=self)

    @property
    def nuttigeLengte(self) -> KwantWrdInMeterWaarden:
        """Afstand gemeten, in meter, volgens de as van de schroefpaal tussen het aanzetpeil van de funderingszool boven de werkvloer (of, in geval van een vrijstaande paal, het afkappeil) en het aanzetpeil (definitief funderingspeil)."""
        return self._nuttigeLengte.get_waarde()

    @nuttigeLengte.setter
    def nuttigeLengte(self, value):
        self._nuttigeLengte.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.OntwerpwaterstandStreefpeil import OntwerpwaterstandStreefpeil
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDVWtoelaatbareSchipsafemetingen import DtcDVWtoelaatbareSchipsafemetingen, DtcDVWtoelaatbareSchipsafemetingenWaarden
from ...Datatypes.DtcOntwerpSchip import DtcOntwerpSchip, DtcOntwerpSchipWaarden
from ...Datatypes.KlKerendeKarakterSluis import KlKerendeKarakterSluis
from ...Datatypes.KlSluisCategorie import KlSluisCategorie
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from ...Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Sluis(OntwerpwaterstandStreefpeil, AIMNaamObject):
    """Waterbouwkundige constructie tussen twee waterlichamen met een verschillend waterpeil. Sluizen hebben als doel het beheersen van het waterpeil en het gecontroleerde doorlaten van schepen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Fuik', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#TijdelijkeWaterkerendeConstructie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VasteWaterbouwkundigeConstructie', direction='i')  # i = direction: incoming

        self._breedte = OTLAttribuut(field=KwantWrdInMeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.breedte',
                                     kardinaliteit_max='*',
                                     definition='De afstand tussen de dagkanten van de vaste constructie, uitgedrukt in meter.',
                                     owner=self)

        self._heeftStopstreep = OTLAttribuut(field=BooleanField,
                                             naam='heeftStopstreep',
                                             label='heeft stopstreep',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.heeftStopstreep',
                                             definition='Geeft aan of er een stopstreep aanwezig is',
                                             owner=self)

        self._isMiddenhoofdAanwezig = OTLAttribuut(field=BooleanField,
                                                   naam='isMiddenhoofdAanwezig',
                                                   label='is middenhoofd aanwezig',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.isMiddenhoofdAanwezig',
                                                   definition='Geeft aan of er een middenhoofd aanwezig is.',
                                                   owner=self)

        self._isOnderhevigAanGetijden = OTLAttribuut(field=BooleanField,
                                                     naam='isOnderhevigAanGetijden',
                                                     label='is onderhevig aan getijden',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.isOnderhevigAanGetijden',
                                                     definition='Geeft aan of de sluis onderhevig aan getijden is.',
                                                     owner=self)

        self._kerendeKarakter = OTLAttribuut(field=KlKerendeKarakterSluis,
                                             naam='kerendeKarakter',
                                             label='kerende karakter',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.kerendeKarakter',
                                             definition='De verschillende kerende karakters van een sluis.',
                                             owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.lengte',
                                    kardinaliteit_max='*',
                                    definition='Lengte langs de kolkwand tussen de meest afwaartse deurkas/-kamer en de meest opwaartse deurkas/-kamer of het opwaarts hoog gefundeerd sluishoofd.',
                                    owner=self)

        self._ontwerpSchip = OTLAttribuut(field=DtcOntwerpSchip,
                                          naam='ontwerpSchip',
                                          label='ontwerp schip',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.ontwerpSchip',
                                          kardinaliteit_max='*',
                                          definition='Schip met afmetingen dat wordt gekozen voor het ontwerp en de berekeningen van de sluis, dat representatief is voor het gemiddelde of typische scheepsverkeer dat naar verwachting de sluis zal gebruiken.',
                                          owner=self)

        self._sluiscategorie = OTLAttribuut(field=KlSluisCategorie,
                                            naam='sluiscategorie',
                                            label='sluiscategorie',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.sluiscategorie',
                                            definition='De verschillende categorieën van sluizen.',
                                            owner=self)

        self._toelaatbareSchipsafmetingen = OTLAttribuut(field=DtcDVWtoelaatbareSchipsafemetingen,
                                                         naam='toelaatbareSchipsafmetingen',
                                                         label='toelaatbare schipsafmetingen',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.toelaatbareSchipsafmetingen',
                                                         definition='Het grootste schip dat door de sluis kan passeren',
                                                         owner=self)

        self._tonnenmaat = OTLAttribuut(field=KwantWrdInTon,
                                        naam='tonnenmaat',
                                        label='tonnenmaat',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.tonnenmaat',
                                        definition='De maximale grootte van schepen, uitgedrukt in tonnen, die de sluis kunnen passeren zonder de capaciteit of de structuur van de sluis te overschrijden.',
                                        owner=self)

        self._vrijeHoogte = OTLAttribuut(field=KwantWrdInMeter,
                                         naam='vrijeHoogte',
                                         label='vrije hoogte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.vrijeHoogte',
                                         definition='De verticale vrije ruimte tussen het wateroppervlak en het laagste punt van de bovenliggende constructie, zoals bruggen, balken of andere obstakels.',
                                         owner=self)

        self._waterdiepte = OTLAttribuut(field=KwantWrdInMeter,
                                         naam='waterdiepte',
                                         label='waterdiepte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis.waterdiepte',
                                         definition='De verticale afstand tussen het wateroppervlak bij gemiddelde laagwaterstand (normale afwaarts pomppeil/ mTAW-waarde) en het laagste punt van de drempel, de sluishoofdvloer of sluiskolkvloer.',
                                         owner=self)

    @property
    def breedte(self) -> List[KwantWrdInMeterWaarden]:
        """De afstand tussen de dagkanten van de vaste constructie, uitgedrukt in meter."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def heeftStopstreep(self) -> bool:
        """Geeft aan of er een stopstreep aanwezig is"""
        return self._heeftStopstreep.get_waarde()

    @heeftStopstreep.setter
    def heeftStopstreep(self, value):
        self._heeftStopstreep.set_waarde(value, owner=self)

    @property
    def isMiddenhoofdAanwezig(self) -> bool:
        """Geeft aan of er een middenhoofd aanwezig is."""
        return self._isMiddenhoofdAanwezig.get_waarde()

    @isMiddenhoofdAanwezig.setter
    def isMiddenhoofdAanwezig(self, value):
        self._isMiddenhoofdAanwezig.set_waarde(value, owner=self)

    @property
    def isOnderhevigAanGetijden(self) -> bool:
        """Geeft aan of de sluis onderhevig aan getijden is."""
        return self._isOnderhevigAanGetijden.get_waarde()

    @isOnderhevigAanGetijden.setter
    def isOnderhevigAanGetijden(self, value):
        self._isOnderhevigAanGetijden.set_waarde(value, owner=self)

    @property
    def kerendeKarakter(self) -> str:
        """De verschillende kerende karakters van een sluis."""
        return self._kerendeKarakter.get_waarde()

    @kerendeKarakter.setter
    def kerendeKarakter(self, value):
        self._kerendeKarakter.set_waarde(value, owner=self)

    @property
    def lengte(self) -> List[KwantWrdInMeterWaarden]:
        """Lengte langs de kolkwand tussen de meest afwaartse deurkas/-kamer en de meest opwaartse deurkas/-kamer of het opwaarts hoog gefundeerd sluishoofd."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def ontwerpSchip(self) -> List[DtcOntwerpSchipWaarden]:
        """Schip met afmetingen dat wordt gekozen voor het ontwerp en de berekeningen van de sluis, dat representatief is voor het gemiddelde of typische scheepsverkeer dat naar verwachting de sluis zal gebruiken."""
        return self._ontwerpSchip.get_waarde()

    @ontwerpSchip.setter
    def ontwerpSchip(self, value):
        self._ontwerpSchip.set_waarde(value, owner=self)

    @property
    def sluiscategorie(self) -> str:
        """De verschillende categorieën van sluizen."""
        return self._sluiscategorie.get_waarde()

    @sluiscategorie.setter
    def sluiscategorie(self, value):
        self._sluiscategorie.set_waarde(value, owner=self)

    @property
    def toelaatbareSchipsafmetingen(self) -> DtcDVWtoelaatbareSchipsafemetingenWaarden:
        """Het grootste schip dat door de sluis kan passeren"""
        return self._toelaatbareSchipsafmetingen.get_waarde()

    @toelaatbareSchipsafmetingen.setter
    def toelaatbareSchipsafmetingen(self, value):
        self._toelaatbareSchipsafmetingen.set_waarde(value, owner=self)

    @property
    def tonnenmaat(self) -> KwantWrdInTonWaarden:
        """De maximale grootte van schepen, uitgedrukt in tonnen, die de sluis kunnen passeren zonder de capaciteit of de structuur van de sluis te overschrijden."""
        return self._tonnenmaat.get_waarde()

    @tonnenmaat.setter
    def tonnenmaat(self, value):
        self._tonnenmaat.set_waarde(value, owner=self)

    @property
    def vrijeHoogte(self) -> KwantWrdInMeterWaarden:
        """De verticale vrije ruimte tussen het wateroppervlak en het laagste punt van de bovenliggende constructie, zoals bruggen, balken of andere obstakels."""
        return self._vrijeHoogte.get_waarde()

    @vrijeHoogte.setter
    def vrijeHoogte(self, value):
        self._vrijeHoogte.set_waarde(value, owner=self)

    @property
    def waterdiepte(self) -> KwantWrdInMeterWaarden:
        """De verticale afstand tussen het wateroppervlak bij gemiddelde laagwaterstand (normale afwaarts pomppeil/ mTAW-waarde) en het laagste punt van de drempel, de sluishoofdvloer of sluiskolkvloer."""
        return self._waterdiepte.get_waarde()

    @waterdiepte.setter
    def waterdiepte(self, value):
        self._waterdiepte.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcBeschermendeLaag import DtcBeschermendeLaag, DtcBeschermendeLaagWaarden
from ...Datatypes.KlAlgMateriaal import KlAlgMateriaal
from ...Datatypes.KlBevestigingssteunMerk import KlBevestigingssteunMerk
from ...Datatypes.KlBevestigingssteunModelnaam import KlBevestigingssteunModelnaam
from ...Datatypes.KlBevestigingssteunType import KlBevestigingssteunType
from ...Datatypes.KlDraagConstrBeschermlaag import KlDraagConstrBeschermlaag
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Bevestigingssteun(AIMNaamObject, PuntGeometrie):
    """Een solide verbindingsstuk waaraan een object kan worden bevestigd ter ondersteuning en bevestiging aan een oppervlak."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gebouw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Zendmast', direction='u')  # u = unidirectional

        self._beschermendeLaag = OTLAttribuut(field=DtcBeschermendeLaag,
                                              naam='beschermendeLaag',
                                              label='beschermende laag',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.beschermendeLaag',
                                              definition='Het type van bescherming van de constructie of steun met de corresponderende corrosieklasse.',
                                              owner=self)

        self._beschermlaag = OTLAttribuut(field=KlDraagConstrBeschermlaag,
                                          naam='beschermlaag',
                                          label='beschermlaag',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.beschermlaag',
                                          usagenote='Attribuut uit gebruik sinds versie 2.12.0',
                                          deprecated_version='2.12.0',
                                          definition='Type bescherming van de steun, bv. geschilderd, gegalvaniseerd, ....',
                                          owner=self)

        self._hoogteBovenkant = OTLAttribuut(field=KwantWrdInMeter,
                                             naam='hoogteBovenkant',
                                             label='hoogte bovenkant',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.hoogteBovenkant',
                                             definition='Hoogte van het maaiveld tot aan de bovenkant van de bevestigingssteun in meter.',
                                             owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMillimeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.lengte',
                                    definition='De lengte van de bevestigingssteun in  millimeter.',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlAlgMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.materiaal',
                                       definition='Het materiaal waaruit de steun vervaardigd is.',
                                       owner=self)

        self._merk = OTLAttribuut(field=KlBevestigingssteunMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.merk',
                                  definition='Het merk van de bevestigingssteun.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlBevestigingssteunModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.modelnaam',
                                       definition='Het model van de bevestigingssteun zoals gekend bij de fabrikant.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlBevestigingssteunType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingssteun.type',
                                  definition='Typering van de bevestigingssteun.',
                                  owner=self)

    @property
    def beschermendeLaag(self) -> DtcBeschermendeLaagWaarden:
        """Het type van bescherming van de constructie of steun met de corresponderende corrosieklasse."""
        return self._beschermendeLaag.get_waarde()

    @beschermendeLaag.setter
    def beschermendeLaag(self, value):
        self._beschermendeLaag.set_waarde(value, owner=self)

    @property
    def beschermlaag(self) -> str:
        """Type bescherming van de steun, bv. geschilderd, gegalvaniseerd, ...."""
        return self._beschermlaag.get_waarde()

    @beschermlaag.setter
    def beschermlaag(self, value):
        self._beschermlaag.set_waarde(value, owner=self)

    @property
    def hoogteBovenkant(self) -> KwantWrdInMeterWaarden:
        """Hoogte van het maaiveld tot aan de bovenkant van de bevestigingssteun in meter."""
        return self._hoogteBovenkant.get_waarde()

    @hoogteBovenkant.setter
    def hoogteBovenkant(self, value):
        self._hoogteBovenkant.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMillimeterWaarden:
        """De lengte van de bevestigingssteun in  millimeter."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de steun vervaardigd is."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de bevestigingssteun."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """Het model van de bevestigingssteun zoals gekend bij de fabrikant."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Typering van de bevestigingssteun."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.BevestigingGC import BevestigingGC
from ...Classes.Abstracten.Deur import Deur
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Vluchtdeur(BevestigingGC, Deur, AIMNaamObject):
    """Deur voor het ontvluchten in geval van calamiteiten weg van de incidentlocatie naar een veilige zone. Een vluchtdeur wordt onder alle omstandigheden zonder sleutel geopend en dit met beperkte kracht."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vluchtdeur'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.9.0'

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aanstraalverlichting', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contourverlichting', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pictogram', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie', direction='o', deprecated='2.9.0')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcExterneReferentie import DtcExterneReferentie, DtcExterneReferentieWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Flitspaal(AIMNaamObject, PuntGeometrie):
    """Buiteninstallatie waarin een flitscamera geplaatst kan worden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Flitspaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Flitscamera', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Flitsgroep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NietSelectieveDetectielus', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersregelaar', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i')  # i = direction: incoming

        self._externeReferentie = OTLAttribuut(field=DtcExterneReferentie,
                                               naam='externeReferentie',
                                               label='externe referentie',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Flitspaal.externeReferentie',
                                               definition='Referentie zoals gekend bij een externe partij bv. aannemer, VLCC, ...',
                                               owner=self)

    @property
    def externeReferentie(self) -> DtcExterneReferentieWaarden:
        """Referentie zoals gekend bij een externe partij bv. aannemer, VLCC, ..."""
        return self._externeReferentie.get_waarde()

    @externeReferentie.setter
    def externeReferentie(self, value):
        self._externeReferentie.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLETrottoirbandType(KeuzelijstField):
    """Types van trottoirband."""
    naam = 'KlLETrottoirbandType'
    label = 'Trottoirband type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLETrottoirbandType'
    definition = 'Types van trottoirband.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLETrottoirbandType'
    options = {
        'beton-type-I-A': KeuzelijstWaarde(invulwaarde='beton-type-I-A',
                                           label='beton type I A',
                                           status='ingebruik',
                                           definitie='type I A',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-A'),
        'beton-type-I-B': KeuzelijstWaarde(invulwaarde='beton-type-I-B',
                                           label='beton type I B',
                                           status='ingebruik',
                                           definitie='type I B',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-B'),
        'beton-type-I-C1': KeuzelijstWaarde(invulwaarde='beton-type-I-C1',
                                            label='beton type I C1',
                                            status='ingebruik',
                                            definitie='type I C1',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-C1'),
        'beton-type-I-C2': KeuzelijstWaarde(invulwaarde='beton-type-I-C2',
                                            label='beton type I C2',
                                            status='ingebruik',
                                            definitie='type I C2',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-C2'),
        'beton-type-I-D1': KeuzelijstWaarde(invulwaarde='beton-type-I-D1',
                                            label='beton type I D1',
                                            status='ingebruik',
                                            definitie='type I D1',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-D1'),
        'beton-type-I-D2': KeuzelijstWaarde(invulwaarde='beton-type-I-D2',
                                            label='beton type I D2',
                                            status='ingebruik',
                                            definitie='type I D2',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-D2'),
        'beton-type-I-D3': KeuzelijstWaarde(invulwaarde='beton-type-I-D3',
                                            label='beton type I D3',
                                            status='ingebruik',
                                            definitie='type I D3',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-D3'),
        'beton-type-I-D4': KeuzelijstWaarde(invulwaarde='beton-type-I-D4',
                                            label='beton type I D4',
                                            status='ingebruik',
                                            definitie='type I D4',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-D4'),
        'beton-type-I-E': KeuzelijstWaarde(invulwaarde='beton-type-I-E',
                                           label='beton type I E',
                                           status='ingebruik',
                                           definitie='type I E',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-E'),
        'beton-type-I-F1': KeuzelijstWaarde(invulwaarde='beton-type-I-F1',
                                            label='beton type I F1',
                                            status='ingebruik',
                                            definitie='type I F1',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-F1'),
        'beton-type-I-F2': KeuzelijstWaarde(invulwaarde='beton-type-I-F2',
                                            label='beton type I F2',
                                            status='ingebruik',
                                            definitie='type I F2',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-F2'),
        'beton-type-I-H': KeuzelijstWaarde(invulwaarde='beton-type-I-H',
                                           label='beton type I H',
                                           status='ingebruik',
                                           definitie='type I H',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/beton-type-I-H'),
        'natuursteen-type-A-I-1': KeuzelijstWaarde(invulwaarde='natuursteen-type-A-I-1',
                                                   label='natuursteen type A I 1',
                                                   status='ingebruik',
                                                   definitie='natuursteen type A I 1',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-A-I-1'),
        'natuursteen-type-A-I-2': KeuzelijstWaarde(invulwaarde='natuursteen-type-A-I-2',
                                                   label='natuursteen type A I 2',
                                                   status='ingebruik',
                                                   definitie='natuursteen type A I 2',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-A-I-2'),
        'natuursteen-type-A-I-3': KeuzelijstWaarde(invulwaarde='natuursteen-type-A-I-3',
                                                   label='natuursteen type A I 3',
                                                   status='ingebruik',
                                                   definitie='natuursteen type A I 3',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-A-I-3'),
        'natuursteen-type-A-II-1': KeuzelijstWaarde(invulwaarde='natuursteen-type-A-II-1',
                                                    label='natuursteen type A II 1',
                                                    status='ingebruik',
                                                    definitie='natuursteen type A II 1',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-A-II-1'),
        'natuursteen-type-A-II-2': KeuzelijstWaarde(invulwaarde='natuursteen-type-A-II-2',
                                                    label='natuursteen type A II 2',
                                                    status='ingebruik',
                                                    definitie='natuursteen type A II 2',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-A-II-2'),
        'natuursteen-type-A-II-3': KeuzelijstWaarde(invulwaarde='natuursteen-type-A-II-3',
                                                    label='natuursteen type A II 3',
                                                    status='ingebruik',
                                                    definitie='natuursteen type A II 3',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-A-II-3'),
        'natuursteen-type-B-I-1': KeuzelijstWaarde(invulwaarde='natuursteen-type-B-I-1',
                                                   label='natuursteen type B I 1',
                                                   status='ingebruik',
                                                   definitie='natuursteen type B I 1',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-B-I-1'),
        'natuursteen-type-B-I-2': KeuzelijstWaarde(invulwaarde='natuursteen-type-B-I-2',
                                                   label='natuursteen type B I 2',
                                                   status='ingebruik',
                                                   definitie='natuursteen type B I 2',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-B-I-2'),
        'natuursteen-type-B-II': KeuzelijstWaarde(invulwaarde='natuursteen-type-B-II',
                                                  label='natuursteen type B II',
                                                  status='ingebruik',
                                                  definitie='natuursteen type B II',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-B-II'),
        'natuursteen-type-C-I-1': KeuzelijstWaarde(invulwaarde='natuursteen-type-C-I-1',
                                                   label='natuursteen type C I 1',
                                                   status='ingebruik',
                                                   definitie='natuursteen type C I 1',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-C-I-1'),
        'natuursteen-type-C-I-2': KeuzelijstWaarde(invulwaarde='natuursteen-type-C-I-2',
                                                   label='natuursteen type C I 2',
                                                   status='ingebruik',
                                                   definitie='natuursteen type C I 2',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-C-I-2'),
        'natuursteen-type-C-II-1': KeuzelijstWaarde(invulwaarde='natuursteen-type-C-II-1',
                                                    label='natuursteen type C II 1',
                                                    status='ingebruik',
                                                    definitie='natuursteen type C II 1',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-C-II-1'),
        'natuursteen-type-C-II-2': KeuzelijstWaarde(invulwaarde='natuursteen-type-C-II-2',
                                                    label='natuursteen type C II 2',
                                                    status='ingebruik',
                                                    definitie='natuursteen type C II 2',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandType/natuursteen-type-C-II-2')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlIoTSensorMerk(KeuzelijstField):
    """IoT-senor merken."""
    naam = 'KlIoTSensorMerk'
    label = 'IoT-sensor merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlIoTSensorMerk'
    definition = 'IoT-senor merken.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlIoTSensorMerk'
    options = {
        'com-sens': KeuzelijstWaarde(invulwaarde='com-sens',
                                     label='COM&SENS',
                                     status='ingebruik',
                                     definitie='COM&SENS',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorMerk/com-sens'),
        'fbgs': KeuzelijstWaarde(invulwaarde='fbgs',
                                 label='FBGS',
                                 status='ingebruik',
                                 definitie='FBGS',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorMerk/fbgs'),
        'leica': KeuzelijstWaarde(invulwaarde='leica',
                                  label='Leica',
                                  status='ingebruik',
                                  definitie='Leica',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorMerk/leica'),
        'rst': KeuzelijstWaarde(invulwaarde='rst',
                                label='RST',
                                status='ingebruik',
                                definitie='RST',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorMerk/rst'),
        'syscom-instruments': KeuzelijstWaarde(invulwaarde='syscom-instruments',
                                               label='SYSCOM Instruments',
                                               status='ingebruik',
                                               definitie='SYSCOM Instruments',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorMerk/syscom-instruments')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Riemspanner(AIMNaamObject, PuntGeometrie):
    """Een riemspanner bestaat meestal uit een rol en veermechanisme en zorgt er voor dat een riem op de gewenste spanning blijft. Een riemspanner is samen met een riemschijf en riem onderdeel van een riemoverbrenging."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Riemspanner'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderstel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Overbrenging', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlStopcontactAantalPolen(KeuzelijstField):
    """Mogelijke waarden voor het aantal polen van een stopcontact."""
    naam = 'KlStopcontactAantalPolen'
    label = 'stopcontact aantal polen'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlStopcontactAantalPolen'
    definition = 'Mogelijke waarden voor het aantal polen van een stopcontact.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlStopcontactAantalPolen'
    options = {
        '3P': KeuzelijstWaarde(invulwaarde='3P',
                               label='3P',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStopcontactAantalPolen/3P'),
        '4P': KeuzelijstWaarde(invulwaarde='4P',
                               label='4P',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStopcontactAantalPolen/4P')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.VegetatieElement import VegetatieElement
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Klimvorm(VegetatieElement, PuntGeometrie):
    """Plant met buigzame stengels die zich aan muren,bomen,enz. hecht en zodoende omhoog klimt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Klimvorm'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._begroeidOppervlak = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                               naam='begroeidOppervlak',
                                               label='begroeid oppervlak',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Klimvorm.begroeidOppervlak',
                                               definition='Verticale oppervlakte dat begroeid is in vierkante meter.',
                                               owner=self)

        self._heeftBeheerScheren = OTLAttribuut(field=BooleanField,
                                                naam='heeftBeheerScheren',
                                                label='heeft beheer scheren',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Klimvorm.heeftBeheerScheren',
                                                definition='Duidt aan of de klimvorm al dan niet geschoren wordt.',
                                                owner=self)

        self._heeftBevestigingconstructie = OTLAttribuut(field=BooleanField,
                                                         naam='heeftBevestigingconstructie',
                                                         label='heeft bevestigingsconstructie',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Klimvorm.heeftBevestigingconstructie',
                                                         definition='Aanduiding of de klimvorm een bevestigingsconstructie heeft om aan bv een geluidswerende constructie vastgemaakt te worden.',
                                                         owner=self)

        self._isGrondgebonden = OTLAttribuut(field=BooleanField,
                                             naam='isGrondgebonden',
                                             label='is grondgebonden',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Klimvorm.isGrondgebonden',
                                             definition='Duidt aan of de klimvorm al dan niet in volle grond staat.',
                                             owner=self)

        self._isZelfhechtend = OTLAttribuut(field=BooleanField,
                                            naam='isZelfhechtend',
                                            label='is zelfhechtend',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Klimvorm.isZelfhechtend',
                                            definition='Geeft aan of de klimplant (zoals klimop of wingerd) rechtstreeks op de muur kan groeien zonder nood aan een draagstructuur.',
                                            owner=self)

    @property
    def begroeidOppervlak(self) -> KwantWrdInVierkanteMeterWaarden:
        """Verticale oppervlakte dat begroeid is in vierkante meter."""
        return self._begroeidOppervlak.get_waarde()

    @begroeidOppervlak.setter
    def begroeidOppervlak(self, value):
        self._begroeidOppervlak.set_waarde(value, owner=self)

    @property
    def heeftBeheerScheren(self) -> bool:
        """Duidt aan of de klimvorm al dan niet geschoren wordt."""
        return self._heeftBeheerScheren.get_waarde()

    @heeftBeheerScheren.setter
    def heeftBeheerScheren(self, value):
        self._heeftBeheerScheren.set_waarde(value, owner=self)

    @property
    def heeftBevestigingconstructie(self) -> bool:
        """Aanduiding of de klimvorm een bevestigingsconstructie heeft om aan bv een geluidswerende constructie vastgemaakt te worden."""
        return self._heeftBevestigingconstructie.get_waarde()

    @heeftBevestigingconstructie.setter
    def heeftBevestigingconstructie(self, value):
        self._heeftBevestigingconstructie.set_waarde(value, owner=self)

    @property
    def isGrondgebonden(self) -> bool:
        """Duidt aan of de klimvorm al dan niet in volle grond staat."""
        return self._isGrondgebonden.get_waarde()

    @isGrondgebonden.setter
    def isGrondgebonden(self, value):
        self._isGrondgebonden.set_waarde(value, owner=self)

    @property
    def isZelfhechtend(self) -> bool:
        """Geeft aan of de klimplant (zoals klimop of wingerd) rechtstreeks op de muur kan groeien zonder nood aan een draagstructuur."""
        return self._isZelfhechtend.get_waarde()

    @isZelfhechtend.setter
    def isZelfhechtend(self, value):
        self._isZelfhechtend.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlMateriaalTaatsschoen import KlMateriaalTaatsschoen
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Taatsschoen(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een onderdeel van het taatsmechanisme dat via een lager contact maakt met de taatspen en is bevestigd aan het beweegbare deel van een bouwkundige constructie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatsschoen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Taatsmechanisme', direction='o')  # o = direction: outgoing

        self._heeftDrukstoel = OTLAttribuut(field=BooleanField,
                                            naam='heeftDrukstoel',
                                            label='heeft drukstoel',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatsschoen.heeftDrukstoel',
                                            definition='Geeft aan of een drukstoel aanwezig is of niet.',
                                            owner=self)

        self._materiaalTaatsschoen = OTLAttribuut(field=KlMateriaalTaatsschoen,
                                                  naam='materiaalTaatsschoen',
                                                  label='materiaal taatsschoen',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatsschoen.materiaalTaatsschoen',
                                                  definition='Het materiaal van de taatsschoen.',
                                                  owner=self)

    @property
    def heeftDrukstoel(self) -> bool:
        """Geeft aan of een drukstoel aanwezig is of niet."""
        return self._heeftDrukstoel.get_waarde()

    @heeftDrukstoel.setter
    def heeftDrukstoel(self, value):
        self._heeftDrukstoel.set_waarde(value, owner=self)

    @property
    def materiaalTaatsschoen(self) -> str:
        """Het materiaal van de taatsschoen."""
        return self._materiaalTaatsschoen.get_waarde()

    @materiaalTaatsschoen.setter
    def materiaalTaatsschoen(self, value):
        self._materiaalTaatsschoen.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlPutbekledingType import KlPutbekledingType
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Putbekleding(AIMObject, PuntGeometrie):
    """De soort afwerkingslaag waarmee een put bekleed is."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Putbekleding'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PutRelatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefGemetenDikte', direction='i')  # i = direction: incoming

        self._laagdikte = OTLAttribuut(field=KwantWrdInMillimeter,
                                       naam='laagdikte',
                                       label='laagdikte',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Putbekleding.laagdikte',
                                       definition='De dikte van de bekledingslaag in millimeter.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlPutbekledingType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Putbekleding.type',
                                  definition='Bepaalt het type van de putbekleding.',
                                  owner=self)

    @property
    def laagdikte(self) -> KwantWrdInMillimeterWaarden:
        """De dikte van de bekledingslaag in millimeter."""
        return self._laagdikte.get_waarde()

    @laagdikte.setter
    def laagdikte(self, value):
        self._laagdikte.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Bepaalt het type van de putbekleding."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ElektrischComponentennummerObject import ElektrischComponentennummerObject
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlDisplayMerk import KlDisplayMerk
from ...Datatypes.KlDisplayModelnaam import KlDisplayModelnaam
from ...Datatypes.KlDisplayType import KlDisplayType
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Display(ElektrischComponentennummerObject, SerienummerObject, AIMNaamObject, PuntGeometrie):
    """Een display is een elektrisch apparaat, ingebed in een techniek, waarop informatie visueel afgebeeld wordt. en dat kan gebruikt voor sturing van die techniek."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Display'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC', direction='u')  # u = unidirectional

        self._isTouchscreen = OTLAttribuut(field=BooleanField,
                                           naam='isTouchscreen',
                                           label='is touchscreen',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Display.isTouchscreen',
                                           definition='Geeft aan of de display een touchscreen is of niet.',
                                           owner=self)

        self._merk = OTLAttribuut(field=KlDisplayMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Display.merk',
                                  definition='Het merk van de display.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlDisplayModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Display.modelnaam',
                                       definition='De modelnaam van de display.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlDisplayType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Display.type',
                                  definition='Geeft aan op welk type technologie de display gebaseerd is.',
                                  owner=self)

    @property
    def isTouchscreen(self) -> bool:
        """Geeft aan of de display een touchscreen is of niet."""
        return self._isTouchscreen.get_waarde()

    @isTouchscreen.setter
    def isTouchscreen(self, value):
        self._isTouchscreen.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de display."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de display."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Geeft aan op welk type technologie de display gebaseerd is."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToegangsdeurTypeOpening(KeuzelijstField):
    """De mogelijke openingtypes van de toegangsdeur."""
    naam = 'KlToegangsdeurTypeOpening'
    label = 'Toegangsdeur type opening'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlToegangsdeurTypeOpening'
    definition = 'De mogelijke openingtypes van de toegangsdeur.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToegangsdeurTypeOpening'
    options = {
        'binnendraaiend': KeuzelijstWaarde(invulwaarde='binnendraaiend',
                                           label='binnendraaiend',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsdeurTypeOpening/binnendraaiend'),
        'buitendraaiend': KeuzelijstWaarde(invulwaarde='buitendraaiend',
                                           label='buitendraaiend',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsdeurTypeOpening/buitendraaiend'),
        'schuivend': KeuzelijstWaarde(invulwaarde='schuivend',
                                      label='schuivend',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsdeurTypeOpening/schuivend')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from ...Classes.Onderdeel.RetroreflecterendVerkeersbord import RetroreflecterendVerkeersbord
from ...Datatypes.KlAantalLampenIVSB import KlAantalLampenIVSB
from ...Datatypes.KlLampTypeIVSB import KlLampTypeIVSB
from ...Datatypes.KlTypeIVSB import KlTypeIVSB
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField


# Generated with OTLClassCreator. To modify: extend, do not edit
class IVSB(NaampadObject, RetroreflecterendVerkeersbord):
    """Een verkeersbord dat door middel van interne verlichtingselementen,zoals LED's,TL-buizen of andere lichtbronnen,van binnenuit wordt verlicht om de leesbaarheid en zichtbaarheid van de verkeersinformatie onder alle lichtomstandigheden te verbeteren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IVSB'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#IVSBGroep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i')  # i = direction: incoming

        self._aantalLampen = OTLAttribuut(field=KlAantalLampenIVSB,
                                          naam='aantalLampen',
                                          label='aantal lampen',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IVSB.aantalLampen',
                                          definition='Het aantal lampen die aanwezig zijn op het bord.',
                                          owner=self)

        self._lampType = OTLAttribuut(field=KlLampTypeIVSB,
                                      naam='lampType',
                                      label='lamp type',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IVSB.lampType',
                                      definition='Het type van de lamp(en) aanwezig in het inwendig verlicht signalisatiebord.',
                                      owner=self)

        self._opschrift = OTLAttribuut(field=StringField,
                                       naam='opschrift',
                                       label='opschrift',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IVSB.opschrift',
                                       definition='Tekst en symbolen die op het bord getoond worden.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlTypeIVSB,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IVSB.type',
                                  definition='Het type inwendig verlicht signalisatiebord.',
                                  owner=self)

    @property
    def aantalLampen(self) -> str:
        """Het aantal lampen die aanwezig zijn op het bord."""
        return self._aantalLampen.get_waarde()

    @aantalLampen.setter
    def aantalLampen(self, value):
        self._aantalLampen.set_waarde(value, owner=self)

    @property
    def lampType(self) -> str:
        """Het type van de lamp(en) aanwezig in het inwendig verlicht signalisatiebord."""
        return self._lampType.get_waarde()

    @lampType.setter
    def lampType(self, value):
        self._lampType.set_waarde(value, owner=self)

    @property
    def opschrift(self) -> str:
        """Tekst en symbolen die op het bord getoond worden."""
        return self._opschrift.get_waarde()

    @opschrift.setter
    def opschrift(self, value):
        self._opschrift.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type inwendig verlicht signalisatiebord."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.StaalsoortObject import StaalsoortObject
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Tandkrans(StaalsoortObject, TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een ringvormige constructie die aan één kant voorzien is van vertanding zoals een tandwiel. Deze tanden grijpen in op een tandwiel. Zo kunnen de rotatie en het koppel van het tandwiel overgebracht worden op de tandkrans die aan een bewegend element is bevestigd zoals bijvoorbeeld een draaibrug."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandkrans'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Tandkransmechanisme', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWegbermBIO(KeuzelijstField):
    """Bijzonder ingerichte onderdelen van de wegbermen."""
    naam = 'KlWegbermBIO'
    label = 'Wegberm BIO'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlWegbermBIO'
    definition = 'Bijzonder ingerichte onderdelen van de wegbermen.'
    status = 'ingebruik'
    deprecated_version = '2.11.0'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWegbermBIO'
    options = {
        'bijzondere-bedding': KeuzelijstWaarde(invulwaarde='bijzondere-bedding',
                                               label='bijzondere bedding',
                                               status='ingebruik',
                                               definitie='Gedeelte van de wegberm, uitsluitend bestemd voor voertuigen van het openbaar vervoer en andere toegelaten voertuigen.',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbermBIO/bijzondere-bedding'),
        'fietspad': KeuzelijstWaarde(invulwaarde='fietspad',
                                     label='fietspad',
                                     status='ingebruik',
                                     definitie='Gedeelte van het wegplatform, dat bestemd is voor fietsers en bromfietsers en als zodanig aangeduid.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbermBIO/fietspad'),
        'ruiterpad': KeuzelijstWaarde(invulwaarde='ruiterpad',
                                      label='ruiterpad',
                                      status='ingebruik',
                                      definitie='Gedeelte van de wegberm, bestemd voor ruiters en als zodanig aangeduid.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbermBIO/ruiterpad'),
        'verkeerseiland': KeuzelijstWaarde(invulwaarde='verkeerseiland',
                                           label='verkeerseiland',
                                           status='ingebruik',
                                           definitie='Heeft als doel het verkeer te geleiden en kan verhoogd zijn.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbermBIO/verkeerseiland'),
        'vluchtheuvel': KeuzelijstWaarde(invulwaarde='vluchtheuvel',
                                         label='vluchtheuvel',
                                         status='ingebruik',
                                         definitie='Verkeersheuvel ten behoeve van voetgangers.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbermBIO/vluchtheuvel'),
        'voetpad': KeuzelijstWaarde(invulwaarde='voetpad',
                                    label='voetpad',
                                    status='ingebruik',
                                    definitie='Gedeelte van de wegberm, bestemd voor voetgangers.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbermBIO/voetpad')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.KlDuurzaamheidsklasseHout import KlDuurzaamheidsklasseHout
from ..Datatypes.KwantWrdInMegaPascal import KwantWrdInMegaPascal, KwantWrdInMegaPascalWaarden
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcKunststofspecificatiesWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._elasticiteitsmodulus = OTLAttribuut(field=KwantWrdInMegaPascal,
                                                  naam='elasticiteitsmodulus',
                                                  label='elasticiteitsmodulus',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKunststofspecificaties.elasticiteitsmodulus',
                                                  definition='Materiaaleigenschap die een maat is voor de stijfheid of starheid van het materiaal, uitgedrukt in N/m² of Pa.',
                                                  owner=self)

        self._naam = OTLAttribuut(field=StringField,
                                  naam='naam',
                                  label='naam',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKunststofspecificaties.naam',
                                  definition='Naam of chemische formule van het kunststof of de samengestelde elementen.',
                                  owner=self)

        self._norm = OTLAttribuut(field=KlDuurzaamheidsklasseHout,
                                  naam='norm',
                                  label='norm',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKunststofspecificaties.norm',
                                  definition='Toegepaste norm op het kunststof voor kwaliteit te testen.',
                                  owner=self)

        self._treksterkte = OTLAttribuut(field=KwantWrdInMegaPascal,
                                         naam='treksterkte',
                                         label='treksterkte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKunststofspecificaties.treksterkte',
                                         definition='Treksterkte van het kunststof door de volgens de norm uitgevoerde trekproef, uitgedrukt in N/m².',
                                         owner=self)

    @property
    def elasticiteitsmodulus(self) -> KwantWrdInMegaPascalWaarden:
        """Materiaaleigenschap die een maat is voor de stijfheid of starheid van het materiaal, uitgedrukt in N/m² of Pa."""
        return self._elasticiteitsmodulus.get_waarde()

    @elasticiteitsmodulus.setter
    def elasticiteitsmodulus(self, value):
        self._elasticiteitsmodulus.set_waarde(value, owner=self._parent)

    @property
    def naam(self) -> str:
        """Naam of chemische formule van het kunststof of de samengestelde elementen."""
        return self._naam.get_waarde()

    @naam.setter
    def naam(self, value):
        self._naam.set_waarde(value, owner=self._parent)

    @property
    def norm(self) -> str:
        """Toegepaste norm op het kunststof voor kwaliteit te testen."""
        return self._norm.get_waarde()

    @norm.setter
    def norm(self, value):
        self._norm.set_waarde(value, owner=self._parent)

    @property
    def treksterkte(self) -> KwantWrdInMegaPascalWaarden:
        """Treksterkte van het kunststof door de volgens de norm uitgevoerde trekproef, uitgedrukt in N/m²."""
        return self._treksterkte.get_waarde()

    @treksterkte.setter
    def treksterkte(self, value):
        self._treksterkte.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcKunststofspecificaties(ComplexField):
    """Complex datatype dat specifieke eigenschappen van de kunststof bevat."""
    naam = 'DtcKunststofspecificaties'
    label = 'Kunststofspecificaties'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKunststofspecificaties'
    definition = 'Complex datatype dat specifieke eigenschappen van de kunststof bevat.'
    waardeObject = DtcKunststofspecificatiesWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kolkwand(AIMNaamObject, LijnGeometrie, VlakGeometrie):
    """De wand van een kolk. Wanden dienen opgesplitst te worden per moot. Elke moot heeft een aparte wand aan beide kanten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolkwand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElementSluisStuw', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondkeringen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolk', direction='o')  # o = direction: outgoing

        self._heeftDraineervoorziening = OTLAttribuut(field=BooleanField,
                                                      naam='heeftDraineervoorziening',
                                                      label='heeft draineervoorziening',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolkwand.heeftDraineervoorziening',
                                                      definition='Geeft aan of er al dan niet een draineervoorziening aanwezig is.',
                                                      owner=self)

    @property
    def heeftDraineervoorziening(self) -> bool:
        """Geeft aan of er al dan niet een draineervoorziening aanwezig is."""
        return self._heeftDraineervoorziening.get_waarde()

    @heeftDraineervoorziening.setter
    def heeftDraineervoorziening(self, value):
        self._heeftDraineervoorziening.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPlantwijze(KeuzelijstField):
    """De mogelijke (aanplant)plantmanieren."""
    naam = 'KlPlantwijze'
    label = 'Plantwijze'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlPlantwijze'
    definition = 'De mogelijke (aanplant)plantmanieren.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPlantwijze'
    options = {
        'in-groep-van-2-5-stuks': KeuzelijstWaarde(invulwaarde='in-groep-van-2-5-stuks',
                                                   label='in groep van 2 - 5 stuks',
                                                   status='ingebruik',
                                                   definitie='0,7 - in groep van 2 - 5 stuks',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlantwijze/in-groep-van-2-5-stuks'),
        'in-groep-van-6-10-stuks': KeuzelijstWaarde(invulwaarde='in-groep-van-6-10-stuks',
                                                    label='in groep van 6 - 10 stuks',
                                                    status='ingebruik',
                                                    definitie='0,6 - in groep van 6 - 10 stuks',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlantwijze/in-groep-van-6-10-stuks'),
        'in-grote-dicht-beplante-groepen': KeuzelijstWaarde(invulwaarde='in-grote-dicht-beplante-groepen',
                                                            label='in grote dicht beplante groepen',
                                                            status='ingebruik',
                                                            definitie='0,4 - in grote dicht beplante groepen (>10 stuks) (ook bosachtige beplantingen, bospark)',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlantwijze/in-grote-dicht-beplante-groepen'),
        'perfecte-rijbeplanting-zonder-uitval': KeuzelijstWaarde(invulwaarde='perfecte-rijbeplanting-zonder-uitval',
                                                                 label='perfecte rijbeplanting (zonder uitval)',
                                                                 status='ingebruik',
                                                                 definitie='0,9 - perfecte rijbeplanting (zonder uitval)',
                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlantwijze/perfecte-rijbeplanting-zonder-uitval'),
        'rijbeplanting-met-belangrijke-uitval': KeuzelijstWaarde(invulwaarde='rijbeplanting-met-belangrijke-uitval',
                                                                 label='rijbeplanting met belangrijke uitval',
                                                                 status='ingebruik',
                                                                 definitie='0,8 - rijbeplanting met belangrijke uitval',
                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlantwijze/rijbeplanting-met-belangrijke-uitval'),
        'solitair': KeuzelijstWaarde(invulwaarde='solitair',
                                     label='solitair',
                                     status='ingebruik',
                                     definitie='1 - solitair',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlantwijze/solitair')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Stroomkring(AIMNaamObject, PuntGeometrie):
    """Ook wel vertrek of vertrekkende kabel genoemd. Afgezekerde elektrische geleiders waarmee de applicaties voorzien worden van de nodige voeding."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FietstelDisplay', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aftakking', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabinecontroller', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LEDDriver', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast', direction='u', deprecated='2.4.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PMU', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelHgLP', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelMHHP', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaLP', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelTL', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voorschakelapparaat', direction='u', deprecated='2.4.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DNBMeter', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aftakking', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dieselgenerator', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ForfaitaireAansluiting', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hoofdschakelaar', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LEDBord', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#MotorVermogenskring', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Sensor', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Flitspaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AIDModule', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera', direction='o', deprecated='2.9.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aanstraalverlichting', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afmetingsensor', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Armatuurcontroller', direction='o', deprecated='2.4.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bewegingssensor', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabinecontroller', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactor', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contourverlichting', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Drukverhogingsgroep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordExternePU', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterAWV', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleidingsverlichting', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hardware', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#InwendigVerlichtPictogram', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LEDDriver', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LKSensorDoorverbinddoos', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lockermanagementmodule', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LuchtkwaliteitControleUnit', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LuchtkwaliteitZenderOntvanger', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLuskaart', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Meetmicrofoon', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast', direction='o', deprecated='2.4.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netstabilisator', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NetwerkModem', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PMU', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTRegelaar', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PoEInjector', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Segmentcontroller', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spanningsomvormer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stopcontact', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tijdschakelaar', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontroller', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UPS', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Veiligheidsrelais', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersregelaar', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verwarmingselement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vooraankondiging', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voorschakelapparaat', direction='o', deprecated='2.4.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WIMDatalogger', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WVOpvoertransformator', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcomputer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Transformator', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UPS', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedingDerdenLaagspanning', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Zonnepaneel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EMAfbakening', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Armatuurcontroller', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IVSB', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast', direction='o')  # o = direction: outgoing

        self._stroomkringnummer = OTLAttribuut(field=StringField,
                                               naam='stroomkringnummer',
                                               label='stroomkringnummer',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring.stroomkringnummer',
                                               definition='De identificatie van de stroomkring.',
                                               owner=self)

    @property
    def stroomkringnummer(self) -> str:
        """De identificatie van de stroomkring."""
        return self._stroomkringnummer.get_waarde()

    @stroomkringnummer.setter
    def stroomkringnummer(self, value):
        self._stroomkringnummer.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kokerventilatie(NaampadObject, VlakGeometrie):
    """Het geheel van ventilatoren, luchtkanalen, sensoren en regelapparatuur om de luchtsnelheid, luchtdruk en luchtsamenstelling in een koker te bewaken en aan te passen aan veranderende omstandigheden, zoals verkeerscongestie of noodsituaties zoals brand."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokerventilatie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Luchtkwaliteitsensor', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Ventilatiecluster', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ventilatierooster', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ..Datatypes.DtcAfmetingBxlInCm import DtcAfmetingBxlInCm, DtcAfmetingBxlInCmWaarden
from ..Datatypes.DtcAfmetingDiameterInCm import DtcAfmetingDiameterInCm, DtcAfmetingDiameterInCmWaarden
from otlmow_model.OtlmowModel.BaseClasses.UnionTypeField import UnionTypeField
from otlmow_model.OtlmowModel.BaseClasses.UnionWaarden import UnionWaarden


# Generated with OTLUnionDatatypeCreator. To modify: extend, do not edit
class DtuAfmetingGrondvlakWaarden(UnionWaarden):
    def __init__(self):
        UnionWaarden.__init__(self)
        self._rechthoekig = OTLAttribuut(field=DtcAfmetingBxlInCm,
                                         naam='rechthoekig',
                                         label='rechthoekig',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtuAfmetingGrondvlak.rechthoekig',
                                         kardinaliteit_min='0',
                                         definition='Afmetingen voor breedte en lengte of diepte. De breedte meet van links naar rechts in vooraanzicht, de lengte van voor naar achter.',
                                         owner=self)

        self._rond = OTLAttribuut(field=DtcAfmetingDiameterInCm,
                                  naam='rond',
                                  label='rond',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtuAfmetingGrondvlak.rond',
                                  kardinaliteit_min='0',
                                  definition='Afmeting van de diameter in centimeter van een rond (grond)vlak.',
                                  owner=self)

    @property
    def rechthoekig(self) -> DtcAfmetingBxlInCmWaarden:
        """Afmetingen voor breedte en lengte of diepte. De breedte meet van links naar rechts in vooraanzicht, de lengte van voor naar achter."""
        return self._rechthoekig.get_waarde()

    @rechthoekig.setter
    def rechthoekig(self, value):
        self._rechthoekig.set_waarde(value, owner=self._parent)
        if value is not None:
            self.clear_other_props('_rechthoekig')

    @property
    def rond(self) -> DtcAfmetingDiameterInCmWaarden:
        """Afmeting van de diameter in centimeter van een rond (grond)vlak."""
        return self._rond.get_waarde()

    @rond.setter
    def rond(self, value):
        self._rond.set_waarde(value, owner=self._parent)
        if value is not None:
            self.clear_other_props('_rond')


# Generated with OTLUnionDatatypeCreator. To modify: extend, do not edit
class DtuAfmetingGrondvlak(UnionTypeField):
    """Datatype voor de afmeting van een (grond)vlak volgens zijn vorm."""
    naam = 'DtuAfmetingGrondvlak'
    label = 'afmeting grondvlak'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtuAfmetingGrondvlak'
    definition = 'Datatype voor de afmeting van een (grond)vlak volgens zijn vorm.'
    waardeObject = DtuAfmetingGrondvlakWaarden

    def __str__(self):
        return UnionTypeField.__str__(self)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Onderdeel.RetroreflecterendVerkeersbord import RetroreflecterendVerkeersbord
from ...Datatypes.KlCalamiteitsbordType import KlCalamiteitsbordType
from ...Datatypes.KlCalamiteitsbordVorm import KlCalamiteitsbordVorm


# Generated with OTLClassCreator. To modify: extend, do not edit
class CalamiteitsBord(RetroreflecterendVerkeersbord):
    """De aanwijzingsborden ter plaatse van een startpunt, een aantakpunt, een wissel- of koppelpunt van een omleggingsroute bij calamiteiten zijn geïntegreerd in een één-bordsysteem met een scharnierende plaat."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CalamiteitsBord'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._calamiteitsbordType = OTLAttribuut(field=KlCalamiteitsbordType,
                                                 naam='calamiteitsbordType',
                                                 label='calamiteitsbord type',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CalamiteitsBord.calamiteitsbordType',
                                                 definition='Het type van calamiteitsbord (bv. draaiend of dragend).',
                                                 owner=self)

        self._vorm = OTLAttribuut(field=KlCalamiteitsbordVorm,
                                  naam='vorm',
                                  label='vorm',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CalamiteitsBord.vorm',
                                  definition='De vorm van het calamiteitsbord.',
                                  owner=self)

    @property
    def calamiteitsbordType(self) -> str:
        """Het type van calamiteitsbord (bv. draaiend of dragend)."""
        return self._calamiteitsbordType.get_waarde()

    @calamiteitsbordType.setter
    def calamiteitsbordType(self, value):
        self._calamiteitsbordType.set_waarde(value, owner=self)

    @property
    def vorm(self) -> str:
        """De vorm van het calamiteitsbord."""
        return self._vorm.get_waarde()

    @vorm.setter
    def vorm(self, value):
        self._vorm.set_waarde(value, owner=self)
